@@ -32,17 +32,34 @@ class UnsplashDownloader(Downloader.Downloader):
     rate_limiting_started_time = 0
 
     CLIENT_ID = '072e5048dfcb73a8d9ad59fcf402471518ff8df725df462b0c4fa665f466515a'
+    UTM_PARAMS = '?utm_source=Variety+Wallpaper+Changer&utm_medium=referral'
+
+    @staticmethod
+    def setWallpaperHook(img, meta):
+        extraData = meta.get('extraData', None)
+        if not extraData:
+            return
+
+        download_loc = extraData.get('unsplashDownloadLocation')
+        reported = extraData.get('unsplashDownloadReported')
+        if download_loc and not reported:
+            url = '{}?client_id={}'.format(download_loc, UnsplashDownloader.CLIENT_ID)
+            Util.fetch(url)
+            meta['extraData']['unsplashDownloadReported'] = True
+            Util.write_metadata(img, meta)
 
     def __init__(self, parent):
         super(UnsplashDownloader, self).__init__(parent, "unsplash", "Unsplash.com", "https://unsplash.com")
         self.last_fill_time = 0
         self.queue = []
 
+        parent.registerDownloaderSetWallpaperHook("unsplash", UnsplashDownloader.setWallpaperHook)
+
     def convert_to_filename(self, url):
         return "Unsplash"
 
     def download_one(self):
-        min_download_interval, min_fill_queue_interval = self.parse_server_options("unsplash", 0, 0)
+        min_download_interval, min_fill_queue_interval = self.parse_server_options("unsplash_v2", 600, 1800)
 
         if time.time() - UnsplashDownloader.last_download_time < min_download_interval:
             logger.info(lambda: "Minimal interval between Unsplash downloads is %d, skip this attempt" % min_download_interval)
@@ -70,8 +87,8 @@ class UnsplashDownloader(Downloader.Downloader):
 
         UnsplashDownloader.last_download_time = time.time()
 
-        origin_url, image_url, extra_metadata, filename = self.queue.pop()
-        return self.save_locally(origin_url, image_url, extra_metadata=extra_metadata, local_filename=filename)
+        origin_url, image_url, extra_metadata = self.queue.pop()
+        return self.save_locally(origin_url, image_url, extra_metadata=extra_metadata)
 
     def fill_queue(self):
         page = random.randint(1, 250)
@@ -89,19 +106,22 @@ class UnsplashDownloader(Downloader.Downloader):
                 if self.parent and not self.parent.size_ok(width, height):
                     continue
 
-                image_url = item['links']['download']
-                origin_url = item['links']['html']
+                image_url = item['urls']['full']
+                origin_url = item['links']['html'] + UnsplashDownloader.UTM_PARAMS
 
-                filename = os.path.join(self.target_folder, Util.sanitize_filename(image_url.split('/')[-2] + '.jpg'))
                 extra_metadata = {
                     'sourceType': 'unsplash',
                     'sfwRating': 100,
                     'author': item['user']['name'],
-                    'authorURL': item['user']['links']['html'],
-                    'keywords': [cat['title'].lower().strip() for cat in item['categories']]
+                    'authorURL': item['user']['links']['html'] + UnsplashDownloader.UTM_PARAMS,
+                    'keywords': [cat['title'].lower().strip() for cat in item['categories']],
+                    'extraData': {
+                        'unsplashDownloadLocation': item['links']['download_location'],
+                        'unsplashDownloadReported': False,
+                    }
                 }
 
-                self.queue.append((origin_url, image_url, extra_metadata, filename))
+                self.queue.append((origin_url, image_url, extra_metadata))
             except:
                 logger.exception(lambda: "Could not process an item from Unsplash")
                 raise
